@@ -25,17 +25,19 @@ class Device:
         If True forces owserver to query the 1wire bus on each property access.
     """
     def __init__(self,
-                 owserver: pyownet.protocol._Proxy,
+                 proxy: pyownet.protocol._Proxy,
                  path: str,
                  uncached: bool = True) -> None:
-        self._owserver = owserver
+        self._proxy = proxy
         self.uncached = uncached
         self.path = path
         self.logger = logging.getLogger(f'{__name__}.{type(self).__name__}')
 
     def __repr__(self) -> str:
-        return (f'{type(self).__name__}({self._owserver}, {self.path}, '
-                f'{self.uncached})')
+        return (f'{type(self).__name__}('
+                f'proxy={self._proxy}, '
+                f'path={self.path}, '
+                f'uncached={self.uncached})')
 
     def _read(self, property: str) -> bytes:
         """
@@ -54,7 +56,7 @@ class Device:
         self.logger.debug(
             f'Trying to read {property} from device: {self.query_path}')
         try:
-            return self._owserver.read(f'{self.query_path}{property}')
+            return self._proxy.read(f'{self.query_path}{property}')
         except pyownet.protocol.Error as ex:
             msg = f'Could not read {property} from device {self.query_path}'
             self.logger.exception(msg)
@@ -75,7 +77,7 @@ class Device:
         self.logger.debug(
             f'Trying to write {property} to device: {self.query_path}')
         try:
-            self._owserver.write(f'{self.query_path}{property}', value)
+            self._proxy.write(f'{self.query_path}{property}', value)
         except pyownet.protocol.Error as ex:
             msg = f'Could not write {property} to device {self.query_path}'
             self.logger.exception(msg)
@@ -99,7 +101,6 @@ class Device:
         Given as upper case hexidecimal digits (0-9A-F).
         Address starts with the family code
         """
-
         return self._read('address').decode('ascii')
 
     @property
