@@ -1,3 +1,5 @@
+import pyownet
+
 from .thermometer import Thermometer
 
 
@@ -9,7 +11,7 @@ class DS18B20(Thermometer):
 
     Parameters
     ----------
-    owserver : pyownet.protocol._Proxy :
+    proxy : pyownet.protocol._Proxy :
         The proxy object used to access the owserver
 
     path : str :
@@ -19,8 +21,11 @@ class DS18B20(Thermometer):
         (Default value = False)
         If True forces owserver to query the 1wire bus on each property access.
     """
-    def __init__(self, owserver, path, uncached=True):
-        super().__init__(owserver, path, uncached=uncached)
+    def __init__(self,
+                 proxy: pyownet.protocol._Proxy,
+                 path: str,
+                 uncached: bool = True) -> None:
+        super().__init__(proxy, path, uncached=uncached)
         self.lower_precision = 9
         self.upper_precision = 12
 
@@ -61,8 +66,6 @@ class DS18B20(Thermometer):
         True if it is powered externally. False if it is powered parasitically
         from the data bus.
         """
-        self.logger.info(
-            f'Trying to read power status for device: {self.query_path}')
         return bool(self._read('power'))
 
     @property
